==> bigloo1.3b.tar.gz: bigloo1.3/recette/number.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1993 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/number.scm ...               */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sat Nov 28 10:52:56 1992                          */
;*    Last change :  Wed Jun 23 16:06:43 1993  (serrano)               */
;*                                                                     */
;*    On test les operateurs generiques sur les nombres                */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module number
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-number)))

;*---------------------------------------------------------------------*/
;*    test-number ...                                                  */
;*---------------------------------------------------------------------*/
(define (test-number)
   (test-module "number" "number.scm" #f)
   (test "=" (= 1 1) #t)
   (test "=" (= 1 2) #f)
   (test "<" (< 1 2) #t)
   (test "<" (< 1 1) #f)
   (test "<" (< 2 1) #f)
   (test ">" (> 1 2) #f)
   (test ">" (> 1 1) #f)
   (test ">" (> 2 1) #t)
   (test ">=" (>= 1 2) #f)
   (test ">=" (>= 1 1) #t)
   (test ">=" (>= 2 1) #t)
   (test "<=" (<= 1 2) #t)
   (test "<=" (<= 1 1) #t)
   (test "<=" (<= 2 1) #f)
   (test "+" (+ 1 2 3 4) 10)
   (test "-" (- 1 2 3 4) -8)
   (test "-" (let ((x 4.0)) (- x)) -4.0)
   (test "*" (* 1 2 3 4) 24)
   (test "/" (/ 12 3 2 1) 2)
   (test "zero?" (zero? 3) #f)
   (test "zero?" (zero? 0) #t)
   (test "zero?" (zero? 3.0) #f)
   (test "zero?" (zero? 0.0) #t)
   (test "positive?" (positive? 5.0) #t)
   (test "positive?" (positive? -5.0) #f)
   (test "positive?" (positive? 5) #t)
   (test "positive?" (positive? -5) #f)
   (test "negative?" (negative? 5.0) #f)
   (test "negative?" (negative? -5.0) #t)
   (test "negative?" (negative? 5) #f)
   (test "negative?" (negative? -5) #t)
   (test "odd?" (odd? 4) #f)
   (test "odd?" (odd? 3) #t)
   (test "even?" (even? 4) #t)
   (test "even?" (even? 3) #f)
   (test "max" (max 3 4) 4)
   (test "max" (max 3.9 4) 4)
   (test "min" (min 3 4) 3)
   (test "min" (min 3.9 4) 3.9)
   (test "modulo" (modulo 13 4) 1)
   (test "remainder" (remainder 13 4) 1)
   (test "modulo" (modulo -13 4) 3)
   (test "remainder" (remainder -13 4) -1)
   (test "modulo" (modulo 13 -4) -3)
   (test "remainder" (remainder 13 -4) 1)
   (test "modulo" (modulo -13 -4) -1)
   (test "remainder" (remainder -13 -4) -1)
   (test "gcd" (gcd 32 -36) 4)
   (test "gcd" (gcd) 0)
   (test "lcm" (lcm 32 -36) 288)
   (test "lcm" (lcm) 1)
   (test "flonum->fixnum" (flonum->fixnum (cosfl 0.0)) 1)
   (test "atan" (tan (atan 1)) (fixnum->flonum 1)))

==> bigloo_1.8b.orig.tar.gz: bigloo-1.8b.orig/recette/number.scm <==
;*---------------------------------------------------------------------*/
;*    Copyright (c) 1996 by Manuel Serrano. All rights reserved.       */
;*                                                                     */
;*                                     ,--^,                           */
;*                               _ ___/ /|/                            */
;*                           ,;'( )__, ) '                             */
;*                          ;;  //   L__.                              */
;*                          '   \    /  '                              */
;*                               ^   ^                                 */
;*                                                                     */
;*                                                                     */
;*    This program is distributed in the hope that it will be useful.  */
;*    Use and copying of this software and preparation of derivative   */
;*    works based upon this software are permitted, so long as the     */
;*    following conditions are met:                                    */
;*           o credit to the authors is acknowledged following         */
;*             current academic behaviour                              */
;*           o no fees or compensation are charged for use, copies,    */
;*             or access to this software                              */
;*           o this copyright notice is included intact.               */
;*      This software is made available AS IS, and no warranty is made */
;*      about the software or its performance.                         */
;*                                                                     */
;*      Bug descriptions, use reports, comments or suggestions are     */
;*      welcome Send them to                                           */
;*        <Manuel.Serrano@inria.fr>                                    */
;*        Manuel Serrano                                               */
;*        INRIA -- Rocquencourt                                        */
;*        Domaine de Voluceau, BP 105                                  */
;*        78153 Le Chesnay Cedex                                       */
;*        France                                                       */
;*---------------------------------------------------------------------*/


;*---------------------------------------------------------------------*/
;*    serrano/prgm/project/bigloo/recette/number.scm                   */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Sat Nov 28 10:52:56 1992                          */
;*    Last change :  Tue Mar 21 11:37:11 1995 (serrano)                */
;*                                                                     */
;*    On test les operateurs generiques sur les nombres                */
;*---------------------------------------------------------------------*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module number
   (import  (main "main.scm"))
   (include "test.sch")
   (export  (test-number)))

;*---------------------------------------------------------------------*/
;*    test-number ...                                                  */
;*---------------------------------------------------------------------*/
(define (test-number)
   (test-module "number" "number.scm" #f)
   (test "=" (= 1 1) #t)
   (test "=" (= 1 1 1) #t)
   (test "=" (= 1 2 1) #f)
   (test "=" (= 1.0 1.0 1.0) #t)
   (test "=" (= 1.0 2.0 1.0) #f)
   (test "<" (< 1 2) #t)
   (test "<" (< 1 1) #f) 
   (test "<" (< 2 1) #f)
   (test "<" (< 1 2 3) #t)
   (test "<" (< 1 2 1 3) #f)
   (test ">" (> 1 2) #f)
   (test ">" (> 1 1) #f)
   (test ">" (> 2 1) #t)
   (test ">" (> 3 2 1) #t)
   (test ">" (> 3 1 2 1) #f)
   (test ">=" (>= 1 2) #f)
   (test ">=" (>= 1 1) #t)
   (test ">=" (>= 2 1) #t)
   (test ">=" (>= 3 2 1) #t)
   (test ">=" (>= 3 1 2 1) #f)
   (test "<=" (<= 1 2) #t)
   (test "<=" (<= 1 1) #t)
   (test "<=" (<= 2 1) #f)
   (test "<=" (<= 1 2 3) #t)
   (test "<=" (<= 1 2 1 3) #f)
   (test "+" (+ 1 2 3 4) 10)
   (test "-" (- 1 2 3 4) -8)
   (test "-" (let ((x 4.0)) (- x)) -4.0)
   (test "*" (* 1 2 3 4) 24)
   (test "/" (/ 12 3 2 1) 2)
   (test "/fx" (/fx 5 4) 1)
   (test "/fx" (integer? (/fx 5 4)) #t)
   (test "zero?" (zero? 3) #f)
   (test "zero?" (zero? 0) #t)
   (test "zero?" (zero? 3.0) #f)
   (test "zero?" (zero? 0.0) #t)
   (test "positive?" (positive? 5.0) #t)
   (test "positive?" (positive? -5.0) #f)
   (test "positive?" (positive? 5) #t)
   (test "positive?" (positive? -5) #f)
   (test "negative?" (negative? 5.0) #f)
   (test "negative?" (negative? -5.0) #t)
   (test "negative?" (negative? 5) #f)
   (test "negative?" (negative? -5) #t)
   (test "odd?" (odd? 4) #f)
   (test "odd?" (odd? 3) #t)
   (test "even?" (even? 4) #t)
   (test "even?" (even? 3) #f)
   (test "max" (max 3 4) 4)
   (test "max" (max 3.9 4) 4)
   (test "min" (min 3 4) 3) 
   (test "min" (min 3.9 4) 3.9)
   (test "modulo" (modulo 13 4) 1)
   (test "remainder" (remainder 13 4) 1)
   (test "modulo" (modulo -13 4) 3)
   (test "remainder" (remainder -13 4) -1)
   (test "modulo" (modulo 13 -4) -3)
   (test "remainder" (remainder 13 -4) 1)
   (test "modulo" (modulo -13 -4) -1)
   (test "remainder" (remainder -13 -4) -1)
   (test "gcd" (gcd 32 -36) 4)
   (test "gcd" (gcd) 0)
   (test "lcm" (lcm 32 -36) 288)
   (test "lcm" (lcm) 1)
   (test "flonum->fixnum" (flonum->fixnum (cosfl 0.0)) 1)
   (test "atan" (tan (atan 1)) (fixnum->flonum 1))
   (test "flofix.<" (< 3.0 3) #f)
   (test "flofix.<" (< 3.1 3) #f)
   (test "flofix.<" (< 3.1 4) #t)
   (test "flofix.>" (> 3 3.0) #f)
   (test "flofix.>" (> 3 3.1) #f)
   (test "flofix.>" (> 4 3.1) #t)
   (test "flofix.<=" (<= 3 3.0) #t)
   (test "flofix.<=" (<= 3 3.1) #t)
   (test "flofix.<=" (<= 3 2.0) #f)
   (test "flofix.>=" (>= 3.0 3) #t)
   (test "flofix.>=" (>= 3.1 3) #t)
   (test "flofix.>=" (>= 3.1 4) #f)
   (let ((x 3.0) (y 3))
      (test "flofix.<" (< x y) #f))
   (let ((x 3.1) (y 3))
      (test "flofix.<" (< x y) #f))
   (let ((x 3.1) (y 4))
      (test "flofix.<" (< x y) #t))
   (let ((x 3) (y 3.0))
      (test "flofix.>" (> x y) #f))
   (let ((x 3) (y 3.1))
      (test "flofix.>" (> x y) #f))
   (let ((x 4) (y 3.1))
      (test "flofix.>" (> x y) #t))
   (let ((x 3) (y 3.0))
      (test "flofix.<=" (<= x y) #t))
   (let ((x 3) (y 3.1))
      (test "flofix.<=" (<= x y) #t))
   (let ((x 3) (y 2.0))
      (test "flofix.<=" (<= x y) #f))
   (let ((x 3.0) (y 3))
      (test "flofix.>=" (>= x y) #t))
   (let ((x 3.1) (y 3))
      (test "flofix.>=" (>= 3.1 3) #t))
   (let ((x 3.1) (y 4))
      (test "flofix.>=" (>= 3.1 4) #f))
   (let ((x -0.2) (y 0))
      (test "flofix.<" (< x y) #t)))
